.. FALCO documentation master file, created by
   sphinx-quickstart on Thu Jun 21 20:18:02 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

MIRAGE: Multi-Instrument RAmp GEnerator
===============================================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   overview.rst
   install.rst
   reference_files.rst
   catalogs.rst
   catalog_creation.rst
   yaml_generator.rst
   example_yaml.rst
   imaging_simulations.rst
   wfss_simulations.rst
   tso_simulations.rst
   three_steps.rst
   seed_images.rst
   dark_preparation.rst
   observation_generator.rst
..   api.rst


Contributors
------------
Mirage is based on early NIRISS simulator software written by Kevin Volk. It has been developed by a group of core contributors from STScI:

- `Bryan Hilbert <https://github.com/bhilbert4>`_
- `Kevin Volk <https://github.com/KevinVolkSTScI>`_
- `Lauren Chambers <https://github.com/laurenmarietta>`_
- `Johannes Sahlmann <https://github.com/Johannes-Sahlmann>`_
- `Shannon Osborne <https://github.com/shanosborne>`_
- `Marshall Perrin <https://github.com/mperrin>`_
- `Nor Pirzkal <https://github.com/npirzkal>`_


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
